summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorsave2010-05-06 15:31:27 +0000
committersave2010-05-06 15:31:27 +0000
commite6cb064510efea1877a98f023cdd0e6104aa3d0b (patch)
tree55941567b9bb475f8d7c765c86ec009dd080ae1f
parentf3f8271afb77db0ea09b14d797264c063b689fad (diff)
cleo/spidupd: add the FMI MME field on SPIDUPD messages, closes #1471
git-svn-id: svn+ssh://pessac/svn/cesar/trunk@6990 017c9cb6-072f-447c-8318-d5b54f68fe89
-rw-r--r--cleopatre/tools/spidupd/spidupd_host.c1
-rw-r--r--cleopatre/tools/spidupd/spidupd_host.h2
-rw-r--r--cleopatre/u-boot-1.1.6/include/net.h3
-rw-r--r--cleopatre/u-boot-1.1.6/net/spidupd.c3
4 files changed, 6 insertions, 3 deletions
diff --git a/cleopatre/tools/spidupd/spidupd_host.c b/cleopatre/tools/spidupd/spidupd_host.c
index 5b71eed12f..8c7bc49e3d 100644
--- a/cleopatre/tools/spidupd/spidupd_host.c
+++ b/cleopatre/tools/spidupd/spidupd_host.c
@@ -108,6 +108,7 @@ prepare_mme_header (connection_t *connect, unsigned char *pkt,
memcpy (hdr->mme_src, connect->host_addr, ETH_ALEN);
hdr->mtype = htons (ETH_P_HPAV);
hdr->mmv = MME_MMV;
+ hdr->fmi = 0;
hdr->mmtype = htommes (mmtype);
}
diff --git a/cleopatre/tools/spidupd/spidupd_host.h b/cleopatre/tools/spidupd/spidupd_host.h
index b4ca459947..61a0cc8339 100644
--- a/cleopatre/tools/spidupd/spidupd_host.h
+++ b/cleopatre/tools/spidupd/spidupd_host.h
@@ -35,6 +35,8 @@ struct MME_t
unsigned char mmv;
/** Management Message Type. */
unsigned short mmtype;
+ /** Fragmentation Management Info. */
+ unsigned short fmi;
} __attribute__ ((__packed__));
typedef struct MME_t MME_t;
diff --git a/cleopatre/u-boot-1.1.6/include/net.h b/cleopatre/u-boot-1.1.6/include/net.h
index 999c1f5d4c..b79acd0df4 100644
--- a/cleopatre/u-boot-1.1.6/include/net.h
+++ b/cleopatre/u-boot-1.1.6/include/net.h
@@ -153,11 +153,10 @@ typedef struct
{
unsigned char mme_dest[6]; /* Destination node */
unsigned char mme_src[6]; /* Source node */
- //unsigned int vlan_tag; /* ieee 802.1q VLAN tag (optional) */
unsigned short mtype; /* 0x88e1 (iee assigned Ethertype) */
unsigned char mmv; /* Management Message Version */
unsigned short mmtype; /* Management Message Type */
- //unsigned short fmi; /* Fragmentation Management Info */
+ unsigned short fmi; /* Fragmentation Management Info */
} __attribute__ ((__packed__)) MME_t;
#define MME_HDR_SIZE 23 /* MME header size (Homeplug AV) */
diff --git a/cleopatre/u-boot-1.1.6/net/spidupd.c b/cleopatre/u-boot-1.1.6/net/spidupd.c
index 6e730eb812..270930b670 100644
--- a/cleopatre/u-boot-1.1.6/net/spidupd.c
+++ b/cleopatre/u-boot-1.1.6/net/spidupd.c
@@ -549,8 +549,9 @@ static void SpidupdSend(void)
ms_update_transfer_cnf = (MsUpdTransfCnf_t *)(mme+1);
ms_update_end_cnf = (MsUpdEndCnf_t *)(mme+1);
/* Set the MME version */
mme->mmv = MME_MMV;
+ mme->fmi = 0;
/* Set MAC Address */
NetSetEther(pkt, NetClientEther, PROT_HPAV);
@@ -549,8 +549,9 @@ static void SpidupdSend(void)
ms_update_transfer_cnf = (MsUpdTransfCnf_t *)(mme+1);
ms_update_end_cnf = (MsUpdEndCnf_t *)(mme+1);
- /* Set the MME version */
+ /* Set the MME version and FMI */
mme->mmv = MME_MMV;